@@ -45,6 +45,7 @@ def set_request_client(client=None, *args, **kwargs):
     if not isinstance(client, RequestClient):
         warning('no request client has been set, using default client')
         client = DefaultRequestClient(*args, **kwargs)
+        client.session.verify = False if os.getenv('RESTAPI_VERIFY_CERT') == 'FALSE' else True
     client = add_standard_headers(client)
     global requestClient
     requestClient = client
@@ -982,6 +983,8 @@ class RESTEndpoint(JsonGetter):
 
         if 'ret_json' not in kwargs:
             kwargs['ret_json'] = True
+        if kwargs.get('stream'):
+            kwargs['ret_json'] = False
         kwargs['client'] = self.client
         return do_request(*args, **kwargs)
 
